PlaywireBannerView class

Inheritance

Constructors

PlaywireBannerView({Key? key, required String adUnitId, bool autoload = true, Map<String, String>? targeting, VoidCallback? onAdLoaded, void onAdFailedToLoad(PlaywireAdError? error)?, VoidCallback? onAdOpened, VoidCallback? onAdClosed, VoidCallback? onAdImpression, VoidCallback? onAdClicked, PlaywireBannerController? controller, int? width, int? height})
const

Properties

adUnitId → String
final
autoload → bool
final
controller → PlaywireBannerController?
final
hashCode → int
The hash code for this object.
no setterinherited
height → int?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAdClicked → VoidCallback?
final
onAdClosed → VoidCallback?
final
onAdFailedToLoad → void Function(PlaywireAdError? error)?
final
onAdImpression → VoidCallback?
final
onAdLoaded → VoidCallback?
final
onAdOpened → VoidCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targeting → Map<String, String>?
final
width → int?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<PlaywireBannerView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited