PlaywireEvent class

Constructors

PlaywireEvent.fromMap(Map<String, dynamic> m)
factory

Properties

appOpen → AppOpenEventType?
final
category → PlaywireEventCategory
final
data → Map<String, dynamic>
final
error → PlaywireAdError?
final
hashCode → int
The hash code for this object.
no setterinherited
interstitial → InterstitialEventType?
final
rewarded → RewardedEventType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdk → SDKEventType?
final
typeName → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited