Playwire class

Constructors

Playwire()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

events → Stream<PlaywireEvent>
no setter

Static Methods

initialize({required String publisherId, required String appId}) → Future<void>
loadAppOpen({required String adUnitId, Map<String, String>? customTargets}) → Future<void>
loadInterstitial({required String adUnitId, Map<String, String>? customTargets}) → Future<void>
loadRewarded({required String adUnitId, Map<String, String>? customTargets}) → Future<void>
setCMP(CMPType type) → Future<void>
setLogLevel(LogLevel level) → Future<void>
setTest(bool enabled) → Future<void>
showAppOpen(String adUnitId) → Future<void>
showInterstitial(String adUnitId) → Future<void>
showRewarded(String adUnitId) → Future<void>
start({required String publisherId, required String appId}) → Future<PlaywireStartResult>